pub struct HalfEdgeId(/* private fields */);Expand description
An index pointing to a half-edge.
This is just a thin newtype wrapper over usize for clarity and to disambiguate it from other index types. Use the [id()] method to access the underlying index.
Implementations